@@ -3,14 +3,19 @@ use std::io::{self, Read};
 use structopt::StructOpt;
 
 #[derive(StructOpt)]
-#[structopt(name = "wd")]
+#[structopt(name = "wd", about="a command line tool for print specified position of words")]
 pub struct CliOptions {
 
+  /// Position of words
   #[structopt(short, long)]
   pub number: Vec<u64>,
+
+  /// Filepath of input
+  #[structopt(short, long)]
+  pub input: Option<String>
 }
 
-fn read_stdin() -> Result<String, String> {
+pub fn read_stdin() -> Result<String, String> {
   let mut buf = String::new();
   let mut stdin = io::stdin();
   match stdin.read_to_string(&mut buf) {
@@ -19,7 +24,6 @@ fn read_stdin() -> Result<String, String> {
   }
 }
 
-pub fn parse_input() -> Result<Vec<String>, String> {
-  let input = read_stdin()?;
-  Ok(input.split_whitespace().map(|str| str.to_string()).collect())
+pub fn parse_input(input: String) -> Vec<String> {
+  input.split_whitespace().map(|str| str.to_string()).collect()
 }
